from .schemas.models import File

TRADE_DAYS = File(key="dim/trade_days.parquet")  # 交易日历
INDEX_DATA = File(key="backtest_data/index.parquet")  # 回测基准指数

CB_DATA = File(key="cb_data.pq")  # 转债回测数据
CB_PRE_QUOTATION = File(key="before_trading/pre_quotations.pq")  # 转债盘前数据
CB_HIST_DATA = File(key="before_trading/hist_data.pq")  # 转债历史行情
CB_QUOTATION = File(key="cb_quotations.pq")  # 转债实时截面

STK_DATA = File(key="backtest_data/stock.parquet")  # 股票回测数据
STK_PRE_QUOTATION = File(key="before_trading_data/stock.parquet")  # 股票盘前数据
STK_HIST_DATA = File(key="before_trading/hist_data_stk.pq")  # 股票历史行情
STK_QUOTATION = File(key="stk_quotations.pq")  # 股票实时截面

FUND_DATA = File(key="backtest_data/fund.parquet")  # 基金回测数据
FUND_PRE_QUOTATION = File(key="before_trading_data/fund.parquet")  # 基金盘前数据
FUND_QUOTATION = File(key="fund_quotations.pq")  # 基金实时截面

# etf_ 方法名保持兼容；底层数据源已升级为 Fund。
ETF_DATA = FUND_DATA
ETF_PRE_QUOTATION = FUND_PRE_QUOTATION
ETF_QUOTATION = FUND_QUOTATION

FINANCE_DATA = File(key="finance/finance.parquet")  # 财报数据
STK_FINA_IND = File(key="backtest_data/stock_fina_ind.parquet")  # 股票财报数据
